@@ -1,9 +1,11 @@
 pub mod authority;
+pub mod path;
 pub mod scheme;
 pub mod uri;
 
 pub use authority::Host;
 pub use authority::Port;
+pub use path::Path;
 pub use scheme::Scheme;
 
 macro_rules! char_colon {
